==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
export let TRIXIndicator = /*@__PURE__*/ (() => {
    class TRIXIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.x6 = 0;
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 9;
            this.trendLinePeriod = 9;
        }
        get_yy() {
            return new TRIXIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return TRIXIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(TRIXIndicator.zk));
        }
        set zj(a) {
            this.h(TRIXIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    TRIXIndicator.$t = /*@__PURE__*/ markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(15, TRIXIndicator.$);
    return TRIXIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/TRIXIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { TRIXIndicatorStrategy } from "./TRIXIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
import { Brush } from "igniteui-react-core";
/**
 * @hidden
 */
export let TRIXIndicator = /*@__PURE__*/ (() => {
    class TRIXIndicator extends StrategyBasedIndicator {
        bj() {
            return new TRIXIndicator();
        }
        constructor() {
            super();
            this.aay = 0;
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 9;
            this.trendLinePeriod = 9;
        }
        get_abq() {
            return new TRIXIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return TRIXIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(TRIXIndicator.acc));
        }
        set acb(a) {
            this.h(TRIXIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    TRIXIndicator.$t = /*@__PURE__*/ markType(TRIXIndicator, 'TRIXIndicator', StrategyBasedIndicator.$);
    TRIXIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(15, TRIXIndicator.$);
    return TRIXIndicator;
})();
